pyjabber.features package
=========================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pyjabber.features.feature_utils
   pyjabber.features.presence

Submodules
----------

pyjabber.features.InBandRegistration module
-------------------------------------------

.. automodule:: pyjabber.features.InBandRegistration
   :members:
   :undoc-members:
   :show-inheritance:

pyjabber.features.ResourceBinding module
----------------------------------------

.. automodule:: pyjabber.features.ResourceBinding
   :members:
   :undoc-members:
   :show-inheritance:

pyjabber.features.SASLFeature module
------------------------------------

.. automodule:: pyjabber.features.SASLFeature
   :members:
   :undoc-members:
   :show-inheritance:

pyjabber.features.StartTLSFeature module
----------------------------------------

.. automodule:: pyjabber.features.StartTLSFeature
   :members:
   :undoc-members:
   :show-inheritance:

pyjabber.features.StreamFeature module
--------------------------------------

.. automodule:: pyjabber.features.StreamFeature
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pyjabber.features
   :members:
   :undoc-members:
   :show-inheritance:
